@@ -11,7 +11,7 @@ class ConfigValidator(object):
                            "experiment_module", "experiment_class"]
 
         for field in required_fields:
-            assert field in config, "Counld not find field {}".format(field)
+            assert field in config, "Could not find field {}".format(field)
 
         assert " " not in config["name"], "Name cant have spaces"
         assert "/" not in config["name"], "Name cant have slashes"
